SendToHub

Struct SendToHub 

#[repr(C)]
pub struct SendToHub { pub selector: U256, pub destination_chain: String, pub payload: Bytes, }
This message is used to route an ITS message via the ITS Hub. The ITS Hub applies certain security checks, and then routes it to the true destination chain. This mode is enabled if the trusted address corresponding to the destination chain is set to the ITS Hub identifier.

struct SendToHub { uint256 selector; string destination_chain; bytes payload; }

Fields

selector: U256

Should always have a value of 3

destination_chain: String

The true destination chain for the ITS call

payload: Bytes

The actual ITS message that’s being routed through ITS Hub

Implementations